==> eiciel-0.1.2.tar.bz2: eiciel-0.1.2/src/eiciel_main_window.hpp <==
#ifndef EICIEL_MAIN_WINDOW_HPP
#define EICIEL_MAIN_WINDOW_HPP

#include <string>
#include <gtkmm.h>
#include "llista_acl.hpp"
#include "eiciel_main_controler.hpp"
#include "tipus_element_acl.hpp"

using namespace std;

class EicielMainControler;


class EicielWindow : public Gtk::Window 
{
	public:
		EicielWindow(EicielMainControler* cont);
		void afegeixNoSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void afegeixSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void buidaLlistaACL();
		void establirNomFitxer(string nomFitxer);
		void activarBotoDefaultACL(bool b);
		void hiHaDefaultACL(bool b);
		bool donaACLDefault();

		virtual ~EicielWindow();
	private:

		Gtk::Button obrirFitxer;
		Gtk::HBox zona_superior;
		Gtk::VBox zona_principal;
		Gtk::Frame marc_inferior;
		Glib::RefPtr<Gtk::ListStore> refLlistaACL;
		Gtk::ScrolledWindow contenidorVistaLlistaACL;
		Gtk::TreeView vistaLlistaACL;
		Gtk::VButtonBox botonera_dreta;
		Gtk::HButtonBox botonera_inferior;
		Gtk::HBox columna_inferior;
		Gtk::Button afegirACL;
		Gtk::CheckButton modificarACLDefault;
		Gtk::Button eliminarACL;
		Gtk::Label nomFitxer;
		Gtk::Button quantA;
		Gtk::Button ajuda;
		EicielMainControler* controlador;
		Gtk::Button sortir;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaMascara;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrupACL;

		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrupACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultMascara;

		ModelLlistaACL modelLlistaACL;
		void noHiHaFitxer();
		void canviDeSeleccio();
		void hiHaSeleccio();
		void noHiHaSeleccio();
		bool funcioSeleccio(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreeModel::Path& path, bool);
		Glib::RefPtr<Gdk::Pixbuf> retornaIconaApropiada(TipusElement e);
		void afegeixElement(string titol, bool lectura, bool escriptura, bool execucio,
				TipusElement e, Gtk::TreeModel::Row& row);
		void eliminarACLSeleccionada();
		void canviPermisos(const Glib::ustring& cadena);
};

#endif

==> eiciel-0.2.3.tar.bz2: eiciel-0.2.3/src/eiciel_main_window.hpp <==
#ifndef EICIEL_MAIN_WINDOW_HPP
#define EICIEL_MAIN_WINDOW_HPP

#include <string>
#include <gtkmm.h>
#include "llista_acl.hpp"
#include "llista_participant.hpp"
#include "eiciel_main_controler.hpp"
#include "tipus_element_acl.hpp"

using namespace std;

class EicielMainControler;


class EicielWindow : public Gtk::Window 
{
	public:
		EicielWindow(EicielMainControler* cont);
		void afegeixNoSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void afegeixSeleccionable(string titol, bool lectura, bool escriptura, bool execucio, TipusElement e);
		void buidaLlistaACL();
		void establirNomFitxer(string nomFitxer);
		void activarBotoDefaultACL(bool b);
		void hiHaDefaultACL(bool b);
		bool donaACLDefault();

		virtual ~EicielWindow();
	private:

		Gtk::Button obrirFitxer;
		Gtk::HBox zona_superior;
		Gtk::VBox zona_principal;
		Gtk::VBox marc_inferior;
        
		Glib::RefPtr<Gtk::ListStore> refLlistaACL;
		Gtk::ScrolledWindow contenidorVistaLlistaACL;
		Gtk::TreeView vistaLlistaACL;
        
        Glib::RefPtr<Gtk::ListStore> refLlistaParticipants;
        Gtk::ScrolledWindow contenidorVistaLlistaParticipants;
        Gtk::TreeView vistaLlistaParticipants;
        
        Gtk::HBox selector_participant;
		Gtk::RadioButton_Helpers::Group tipusACL;
		Gtk::RadioButton ACLusuari;
		Gtk::RadioButton ACLgrup;
        Gtk::CheckButton aclDefault;
		Gtk::ToggleButton modificarACLDefault;

		Gtk::VButtonBox botonera_dreta;
		Gtk::HButtonBox botonera_inferior;
		Gtk::HButtonBox botonera_mig;
		Gtk::Button afegirACL;
		//Gtk::CheckButton modificarACLDefault;
		Gtk::Button eliminarACL;
		Gtk::Label nomFitxer;
		Gtk::Button quantA;
		Gtk::Button ajuda;
		EicielMainControler* controlador;
		Gtk::Button sortir;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaMascara;

		Glib::RefPtr<Gdk::Pixbuf> iconaUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaGrupACL;

		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuari;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrup;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultAltres;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultUsuariACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultGrupACL;
		Glib::RefPtr<Gdk::Pixbuf> iconaDefaultMascara;

		ModelLlistaACL modelLlistaACL;
        ModelLlistaParticipant modelLlistaParticipant;

		void noHiHaFitxer();
		void canviDeSeleccioACL();
		void hiHaSeleccioACL();
		void noHiHaSeleccioACL();

		void canviDeSeleccioParticipant();
		void hiHaSeleccioParticipant();
		void noHiHaSeleccioParticipant();
		bool funcioSeleccioACL(const Glib::RefPtr<Gtk::TreeModel>& model,
				const Gtk::TreeModel::Path& path, bool);
		Glib::RefPtr<Gdk::Pixbuf> retornaIconaApropiada(TipusElement e);
		void afegeixElement(string titol, bool lectura, bool escriptura, bool execucio,
				TipusElement e, Gtk::TreeModel::Row& row);
		void eliminarACLSeleccionada();
		void afegirParticipantSeleccionat();
		void canviPermisos(const Glib::ustring& cadena);

        void emplenarUsuaris();
        void emplenarGrups();
};

#endif
